Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/nextcloudpi.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authornachoparker <nacho@ownyourbits.com>2018-05-24 20:28:28 +0300
committernachoparker <nacho@ownyourbits.com>2018-05-27 21:32:36 +0300
commit06c07d33ee3a3154e41a3d7eca4fd778e0400267 (patch)
treeaa923b3a214711b57cc92d28a561c7a3cf17c1d3 /install.sh
parent027a2a02bddfad3152d00de6b2134a9d8b21edbf (diff)
Rework raspbian build system
Diffstat (limited to 'install.sh')
-rw-r--r--install.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/install.sh b/install.sh
index 42d4bc49..84cacba8 100644
--- a/install.sh
+++ b/install.sh
@@ -1,6 +1,6 @@
#!/bin/bash
# NextCloudPlus installation script
#
# Copyleft 2017 by Ignacio Nunez Hernanz <nacho _a_t_ ownyourbits _d_o_t_ com>
# GPL licensed (see end of file) * Use at your own risk!
@@ -14,7 +14,7 @@ BRANCH=master
set -e$DBG
-TMPDIR="$(mktemp -d /tmp/nextcloudplus.XXXXXX || (echo "Failed to create temp dir. Exiting" >&2 ; exit 1) )"
+TMPDIR="$(mktemp -d /tmp/nextcloudpi.XXXXXX || (echo "Failed to create temp dir. Exiting" >&2 ; exit 1) )"
trap "rm -rf \"${TMPDIR}\" ; exit 0" 0 1 2 3 15
[[ ${EUID} -ne 0 ]] && {
@@ -44,13 +44,13 @@ wget -O- --content-disposition https://github.com/nextcloud/nextcloudpi/archive/
cd - && cd "$TMPDIR"/nextcloudpi-"$BRANCH"
# install NCP
-echo -e "\nInstalling NextCloudPlus"
+echo -e "\nInstalling NextCloudPi"
source etc/library.sh
install_script lamp.sh
install_script etc/ncp-config.d/nc-nextcloud.sh
activate_script etc/ncp-config.d/nc-nextcloud.sh
-install_script nextcloudplus.sh
+install_script ncp.sh
activate_script etc/ncp-config.d/nc-init.sh
# re-enable mods disabled during install, in case there's other shared services in apache2
@@ -1,6 +1,6 @@
#!/bin/bash
-# NextCloudPlus installation script
+# NextCloudPi installation script
#
# Copyleft 2017 by Ignacio Nunez Hernanz <nacho _a_t_ ownyourbits _d_o_t_ com>